@@ -31,13 +31,13 @@ from akangatu.linalghelper import islazy
 from akangatu.transf.step import Step
 from garoupa.uuid import UUID
 from tatu.abs.mixin.thread import asThread
-from tatu.abs.storage import Storage, DuplicateEntryException
+from tatu.abs.storage import Storage, DuplicateEntryException, LockedEntryException
 
 
 class StorageInterface(asThread, Storage, ABC):
     # TODO (strict) fetch by uuid
     # TODO (strict) store
-    def fetch(self, data, lock=False, lazy=True):
+    def fetch(self, data, lock=False, lazy=True, ignorelock=False):
         # , recursive=True):   # TODO: pensar no include_empty=False se faz sentido
         """Fetch the data object fields on-demand.
          data: uuid string or a (probably still not fully evaluated) Data object."""
@@ -45,7 +45,13 @@ class StorageInterface(asThread, Storage, ABC):
         # lst = []
         # print("LOGGING:::  Fetching...", data_id)
         # while True:
-        ret = self.getdata(data_id, include_empty=True)
+        try:
+            ret = self.getdata(data_id, include_empty=True)
+        except LockedEntryException:
+            if not ignorelock:
+                raise None
+            ret = None
+            lock = False  # Already locked.
 
         if ret is None or not ret["uuids"]:
             # REMINDER: check_existence false porque pode ser um data vazio
@@ -75,7 +81,7 @@ class StorageInterface(asThread, Storage, ABC):
                     fields[field] = unpack(self.getcontent(fid))
 
             # Call each lambda by a friendly name.
-            if lazy and field != "changed":  # and field in data.field_funcs_m:
+            if lazy and field != "changed" and islazy(fields[field]):  # and field in data.field_funcs_m:
                 fields[field].__name__ = "_" + fields[field].__name__ + "_from_storage_" + self.id
 
         if isinstance(data, str):
@@ -112,7 +118,7 @@ class StorageInterface(asThread, Storage, ABC):
         :param check_dup:
         :param recursive:
         """
-        if not ignoredup and self.hasdata(data.id):
+        if not ignoredup and self.hasdata(data.id) and not unlock:
             raise DuplicateEntryException(data.id)
 
         # Embed lazy storers inside the Data object.
@@ -160,12 +166,13 @@ class StorageInterface(asThread, Storage, ABC):
                         # Consume stream, to be stored after putdata().
                         streams[data.id] = list(data.stream)
                     else:
-                        id = data.uuids[k].id
-                        if id in missing and k != "inner" and k != "stream":
-                            content = fpack(data, k)
-                            # TODO/REMINDER: exceptionally two datasets can have some equal contents, like Xd;
-                            #   so we send it again while the hash is not based on content
-                            self.putcontent(id, content, ignoredup=True)
+                        if k != "inner" and k != "stream":
+                            id = data.uuids[k].id
+                            if id in missing:
+                                content = fpack(data, k)
+                                # TODO/REMINDER: exceptionally two datasets can have some equal contents, like Xd;
+                                #   so we send it again while the hash is not based on content
+                                self.putcontent(id, content, ignoredup=True)
 
             lst.append(data)
             if not data.hasinner:
@@ -206,7 +213,7 @@ class StorageInterface(asThread, Storage, ABC):
                         rows.append((d.id, str(pos), streamed_data.id))
                     if not rows:
                         raise Exception("Empty stream??")
-                    self.putstream(rows)
+                    self.putstream(rows, ignoredup=ignoredup)
 
                     # Return a new iterator in the place of the original stream.
                     d.field_funcs_m["stream"] = iter(streams[d.id])
